@@ -1,4 +1,4 @@
-package Pcore::Redis v0.6.2;
+package Pcore::Redis v0.6.3;
 
 use Pcore -dist, -class;
 
@@ -14,6 +14,8 @@ sub run ( $self, $cb ) {
 
     $self->store_config($cfg);
 
+    say "PASSWORD: $cfg->{requirepass}";
+
     # run server
     P->pm->run_proc(
         [ 'redis-server', '--include', $self->data_dir . '/redis.conf' ],
@@ -99,9 +101,9 @@ sub default_config ( $self ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 46                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 48                   | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 90                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
+## |    3 | 92                   | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -116,10 +118,11 @@ Pcore::Redis
 
 =head1 SYNOPSIS
 
-    docker create --name redis -v redis:/var/local/pcore-redis/data/ -v /tmp/redis.sock:/tmp/redis.sock -p 6379:6379/tcp softvisio/redis
-
     docker create --name redis -v redis:/var/local/pcore-redis/data/ -p 6379:6379/tcp softvisio/redis
 
+    # !!!WARNING!!! do not use unix sockets, config is not ready yet
+    docker create --name redis -v redis:/var/local/pcore-redis/data/ -v /tmp/redis.sock:/tmp/redis.sock -p 6379:6379/tcp softvisio/redis
+
     # connect via TCP
     my $h = P->handle('redis://password@host:port?db=dbindex');
 
